@@ -61,42 +61,34 @@ def parse_url(url):
 class BrokerConnection(object):
     """A connection to the broker.
 
-    :keyword hostname: Hostname/address of the server to connect to.
-      Default is ``"localhost"``.
-    :keyword userid: Username. Default is ``"guest"``.
-    :keyword password: Password. Default is ``"guest"``.
-    :keyword virtual_host: Virtual host. Default is ``"/"``.
-    :keyword port: Port of the server. Default is transport specific.
-    :keyword insist: Insist on connecting to a server.
-      In a configuration with multiple load-sharing servers, the insist
-      option tells the server that the client is insisting on a connection
-      to the specified server.  Default is ``False``.
+    :param URL:  Connection URL.
+
+    :keyword hostname: Default Hostname/address if not provided in the URL.
+    :keyword userid: Default username if not provided in the URL.
+    :keyword password: Default password if not provided in the URL.
+    :keyword virtual_host: Default virtual host if not provided in the URL.
+    :keyword port: Default port if not provided in the URL.
     :keyword ssl: Use ssl to connect to the server. Default is ``False``.
-    :keyword transport: Transport class to use. Can be a class,
-         or a string specifying the path to the class. (e.g.
-         ``kombu.transport.pyamqplib.Transport``), or one of the aliases:
-         ``amqplib``, ``pika``, ``redis``, ``memory``.
+      May not be supported by the specified transport.
+    :keyword transport: Default transport if not specified in the URL.
     :keyword connect_timeout: Timeout in seconds for connecting to the
       server. May not be suported by the specified transport.
     :keyword transport_options: A dict of additional connection arguments to
       pass to alternate kombu channel implementations.  Consult the transport
       documentation for available options.
+    :keyword insist: *Deprecated*
 
-    **Usage**
+    .. note::
 
-    Creating a connection::
+        The connection is established lazily when needed. If you need the
+        connection to be established, then force it to do so using
+        :meth:`connect`::
 
-        >>> conn = BrokerConnection("rabbit.example.com")
+            >>> conn.connect()
 
-    The connection is established lazily when needed. If you need the
-    connection to be established, then force it to do so using
-    :meth:`connect`::
+        Remember to always close the connection::
 
-        >>> conn.connect()
-
-    Remember to always close the connection::
-
-        >>> conn.release()
+            >>> conn.release()
 
     """
     URI_FORMAT = URI_FORMAT
@@ -460,6 +452,18 @@ class BrokerConnection(object):
         """
         return ChannelPool(self, limit, preload)
 
+    def Producer(self, channel=None, *args, **kwargs):
+        from kombu.messaging import Producer
+        if channel is None:
+            channel = self   # use default channel support.
+        return Producer(channel, *args, **kwargs)
+
+    def Consumer(self, channel=None, *args, **kwargs):
+        from kombu.messaging import Consumer
+        if channel is None:
+            channel = self  # use default channel support.
+        return Consumer(channel, *args, **kwargs)
+
     def SimpleQueue(self, name, no_ack=None, queue_opts=None,
             exchange_opts=None, channel=None, **kwargs):
         """Create new :class:`~kombu.simple.SimpleQueue`, using a channel
@@ -535,6 +539,13 @@ class BrokerConnection(object):
     def __exit__(self, *args):
         self.release()
 
+    @property
+    def connected(self):
+        """Returns true if the connection has been established."""
+        return (not self._closed and
+                self._connection is not None and
+                self.transport.verify_connection(self._connection))
+
     @property
     def connection(self):
         """The underlying connection object.
@@ -544,13 +555,11 @@ class BrokerConnection(object):
             depend on the interface of this object.
 
         """
-        if self._closed:
-            return
-        if not self._connection or not \
-                self.transport.verify_connection(self._connection):
-            self._connection = self._establish_connection()
-            self._closed = False
-        return self._connection
+        if not self._closed:
+            if not self.connected:
+                self._connection = self._establish_connection()
+                self._closed = False
+            return self._connection
 
     @property
     def default_channel(self):
@@ -729,11 +738,9 @@ class PoolChannelContext(object):
 
     def __enter__(self):
         self.conn = self.pool.acquire(block=self.block)
-        self.chan = self.conn.channel()
-        return self.conn, self.chan
+        return self.conn, self.conn.default_channel
 
     def __exit__(self, *exc_info):
-        self.conn.maybe_close_channel(self.chan)
         self.conn.release()
 
 
