@@ -64,7 +64,12 @@ class Producer(object):
     def __init__(self, channel, exchange=None, routing_key=None,
             serializer=None, auto_declare=None, compression=None,
             on_return=None):
+        from kombu.connection import BrokerConnection
+        if isinstance(channel, BrokerConnection):
+            channel = channel.default_channel
         self.channel = channel
+        self.connection = self.channel.connection.client
+
         self.exchange = exchange or self.exchange
         if self.exchange is None:
             self.exchange = Exchange("")
@@ -224,7 +229,12 @@ class Consumer(object):
 
     def __init__(self, channel, queues, no_ack=None, auto_declare=None,
             callbacks=None, on_decode_error=None):
+        from kombu.connection import BrokerConnection
+        if isinstance(channel, BrokerConnection):
+            channel = channel.default_channel
         self.channel = channel
+        self.connection = self.channel.connection.client
+
         self.queues = queues
         if no_ack is not None:
             self.no_ack = no_ack
@@ -304,6 +314,7 @@ class Consumer(object):
         for tag in self._active_tags.values():
             self.channel.basic_cancel(tag)
         self._active_tags.clear()
+    close = cancel
 
     def cancel_by_queue(self, queue):
         """Cancel consumer by queue name."""
